:******************************************************************************
:* Product:  MpStart version 1.2.0 (2024-05-07)
:* Purpose:  Install the MpStart Support Pack.
:* Author:   CyberSimian (contact via fora at: www.team-mediaportal.com)
:*
:* Invocation:  install.bat [/?] [/u]
:*
:* Notes:
:* 1.  Refer to "MpStart.txt" for further details.
:******************************************************************************
@echo off
setlocal EnableDelayedExpansion
:*
:* check if help requested
if "%1" equ "/?" goto explain
:*
echo.
echo.====================
echo.MpStart Support Pack
echo.====================
echo.
:*
:* set target drive
set tgt_drv=%SystemDrive%
:*
:******************************************************************************
:* check that AutoHotKey is installed
set line=
if exist "assoc.out" del "assoc.out"
if exist "assoc.err" del "assoc.err"
assoc .ahk 1>"assoc.out" 2>"assoc.err"
set /p line= <"assoc.out"
if exist "assoc.out" del "assoc.out"
if exist "assoc.err" del "assoc.err"
if "%line%" equ "" (
  echo.AutoHotKey not found. Please install AutoHotKey version 2.
  set errorlevel=101
  goto finish
)
:*
:******************************************************************************
:* check that AutoHotKey version 2 is available
set ftype=%line:~5%
:* echo ftype: [%ftype%]
set line=
if exist "ftype.out" del "ftype.out"
if exist "ftype.err" del "ftype.err"
ftype %ftype% 1>"ftype.out" 2>"ftype.err"
set /p line= <"ftype.out"
if exist "ftype.out" del "ftype.out"
if exist "ftype.err" del "ftype.err"
:* echo line: [%line%]
:* note: the response from FTYPE can have multiple quotes embedded within it,
:* and these cause the IF test to malfunction; so we need to remove the quotes
:* before testing for a null response.
set line=%line:"=%
:* echo line: [%line%]
if "%line%" equ "" (
  echo.No command line defined for file type %ftype%; refer to FTYPE command.
  set errorlevel=102
  goto finish
)
:* now remove "\launcher.ahk" (if present)
set test=%line:\launcher.ahk=%
:* echo test: [%test%]
if "test" equ "line" (
  echo.AutoHotKey version 2 not found. Please install AutoHotKey version 2.
  set errorlevel=103
  goto finish
)
:*
:******************************************************************************
:* get windows version
:*   4.10 = Windows 98
:*   5.0  = Windows 2000
:*   5.1  = Windows XP
:*   5.2  = Windows XP x64
:*   6.0  = Windows Vista
:*   6.1  = Windows 7
:*   6.2  = Windows 8
:*   6.3  = Windows 8.1 and Windows Server 2012
:*  10.0  = Windows 10 and Windows 11
for /f "tokens=4-7 delims=[.] " %%i in ('ver') do (
if "%%i" equ "Version" (set win_ver=%%j.%%k) else (set win_ver=%%i.%%j)
)
:*
:******************************************************************************
:* set target folders for startup shortcut (depends on Windows version)
if "%win_ver%" equ "5.1"  goto win_xp
if "%win_ver%" equ "5.2"  goto win_xp
:*
:* win vista/7/8.0/8.1/10/11
set all_users=%tgt_drv%\ProgramData\Microsoft\Windows
set this_user=%tgt_drv%\Users\%UserName%\AppData\Roaming\Microsoft\Windows
goto win_common
:*
:win_xp
set all_users=%tgt_drv%\Documents and Settings\All Users
set this_user=%tgt_drv%\Documents and Settings\%UserName%
:*
:win_common
set all_users=%all_users%\Start Menu\Programs\Startup
set this_user=%this_user%\Start Menu\Programs\Startup
:*
:******************************************************************************
:* set source and target folders
set src_folder=%~dp0
set src_folder=%src_folder:~0,-1%
set tgt_folder=%tgt_drv%\ProgramData\Team MediaPortal\MediaPortal
:*
:******************************************************************************
:* check that we are not running from a "Team MediaPortal" folder
set run_folder=%src_folder%\
set run_edited=%run_folder:\Team MediaPortal\=%
if /i "%run_folder%" neq "%run_edited%" (
  echo.The support pack must not reside in a "Team MediaPortal" folder.
  echo.Please move the support pack to a different folder.
  set errorlevel=104
  goto finish
)
:*
:******************************************************************************
:* uninstall the existing support pack (if any)
:******************************************************************************
if /i "%1" equ "/u" (
  echo.Uninstalling Support Pack.
  echo.
  echo.Terminating AutoHotKey script "MpTrap.ahk".
)
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
if exist "%tgt_folder%\MpStart.ahk" "%tgt_folder%\MpStart.ahk" :EXIT:
call :delete_file "%tgt_folder%\MpStart.ahk"
if "%errorlevel%" neq "0" goto finish
call :delete_file "%tgt_folder%\MpStart.ini"
if "%errorlevel%" neq "0" goto finish
call :delete_file "%tgt_folder%\MpTrap.ahk"
if "%errorlevel%" neq "0" goto finish
call :delete_file "%this_user%\MpTrap.lnk"
if "%errorlevel%" neq "0" goto finish
call :delete_file "%all_users%\MpTrap.lnk"
if "%errorlevel%" neq "0" (
  echo.Try again using "Run as Administrator".
  goto finish
)
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
if /i "%1" equ "/u" (
  echo.
  echo.Uninstall successful.
  set errorlevel=0
  goto finish
)
:*
:******************************************************************************
:* install new support pack
:******************************************************************************
echo.Installing Support Pack.
echo.
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
echo.Installing:  "MpStart.ahk"
call :copy_file "%src_folder%\MpStart.ahk" "%tgt_folder%"
if "%errorlevel%" neq "0" goto finish
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
echo.Installing:  "MpStart.ini"
call :copy_file "%src_folder%\MpStart.ini" "%tgt_folder%"
if "%errorlevel%" neq "0" goto finish
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
echo.Installing:  "MpTrap.ahk"
call :copy_file "%src_folder%\MpTrap.ahk" "%tgt_folder%"
if "%errorlevel%" neq "0" goto finish
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
echo.Installing:  "MpTrap.lnk"  (for all users)
set lnk_spec=%all_users%\MpTrap.lnk
copy "%src_folder%\MpTrap.lnk" "%lnk_spec%"
if not errorlevel 1 goto copy_lnk_ok
echo.Cannot copy LNK file to "all users" startup folder.
echo.Trying startup folder for current user instead.
echo.Installing:  "MpTrap.lnk"  (for current user)
set lnk_spec=%this_user%\MpTrap.lnk
call :copy_file "%src_folder%\MpTrap.lnk" "%lnk_spec%"
if "%errorlevel%" neq "0" goto finish
:copy_lnk_ok
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
:* invoke the shortcut to start the AutoHotKey script
echo.Starting AutoHotKey script "MpTrap.ahk".
:* note: AHK errors are not returned by "rundll32.exe".
set errorlevel=
rundll32.exe shell32.dll,ShellExec_RunDLL "%lnk_spec%"
if "%errorlevel%" neq "0" (
  echo.Error starting "MpTrap.ahk", error code: %errorlevel%.
  goto finish
)
:* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
echo.
echo.Install successful.
set errorlevel=0
goto finish
:*
:******************************************************************************
:* common exit point
:******************************************************************************
:finish
echo.
set /p reply=Press the ENTER or RETURN key to finish (return code %errorlevel%).
exit /b %errorlevel%
:*
:******************************************************************************
: copy_file function
:******************************************************************************
:* Notes:
:* 1.  "exit" here does not exit "install.bat"; instead it returns to the line
:*     following the function invocation.
:******************************************************************************
:copy_file
if exist %1 (
  copy %1 %2
  if errorlevel 1 (
    echo.Unexpected error copying file:
    echo.  source:  %1
    echo.  target:  %2
    exit /b 105
  )
)
exit /b 0
:*
:******************************************************************************
: delete_file function
:******************************************************************************
:* Notes:
:* 1.  "del" command sets neither "errorlevel" nor "%errorlevel%".
:* 2.  "exit" here does not exit "install.bat"; instead it returns to the line
:*     following the function invocation.
:******************************************************************************
:delete_file
if exist %1 (
  del %1 1>nul 2>nul
  if exist %1 (
    echo.Unable to delete file:
    echo.  %1
    exit /b 106
  )
)
exit /b 0
:*
:******************************************************************************
:* display help information
:******************************************************************************
:explain
echo.
echo.Use INSTALL.BAT to install the MpStart Support Pack.
echo.Syntax:
echo.  INSTALL.BAT [/?]
echo.Options:
echo.  /? -- Display this help information.
echo.Notes:
echo.1.  Run this BAT file from a dedicated folder that contains all of
echo.    the files in the MpStart support pack. Do not use a folder that
echo.    resides in the "Team MediaPortal" folder tree.
echo.2.  At the end of installation, the support pack is activated. A
echo.    shortcut is placed in your startup folder to activate the
echo.    support pack each time that you boot your system.
echo.3.  The shortcut is placed in the "All Users" startup folder as a
echo.    first choice, but if that fails, the shortcut is placed in the
echo.    startup folder for the current user.
echo.4.  To install in the "All Users" startup folder, you must run this
echo.    BAT file with Administrator privileges. Right click "INSTALL.BAT"
echo.    and left click "Run as administrator".
echo.5.  The support pack requires that AutoHotKey version 2 is installed.
echo.    Please install that version of AutoHotKey before installing the
echo.    support pack.
echo.6.  Use UNINSTALL.BAT to uninstall the MpStart Support Pack.
echo.
exit /b 0
:******************************************************************************
